NLSL: rnddbl.f90 File Reference

NLSL

- Main Page
- Modules
- Data Types List
- Files

- File List
- File Members

Modules | Variables
rnddbl.f90 File Reference

Go to the source code of this file.

## Modules
module | rnddbl

## Variables
double precision, parameter | rnddbl::dbl_epsilon =2.2204460492503131D-16
double precision, parameter | rnddbl::dbl_min =2.2250738585072014D-308
double precision, parameter | rnddbl::dbl_max =1.7976931348623157D+308
double precision, parameter | rnddbl::rndoff =DBL_EPSILON